import axios from 'axios'
import type {
  LoginRequest,
  LoginResponse,
  RegisterRequest,
  RegisterResponse,
  Ticket,
  TicketInfo,
  GetValidationTicketsRequest,
  GetValidationTicketsResponse,
  GetValidationTicketByIdResponse,
  UpdateValidationStatusByTicketIdRequest,
  UpdateValidationStatusByTicketIdResponse,
  CompanyValidationTicket,
  DashboardData
} from '../types/api'

const API_URL = import.meta.env.VITE_API_URL || 'http://localhost:8080'

const api = axios.create({
  baseURL: API_URL,
  headers: {
    'Content-Type': 'application/json',
  },
})

// Add auth token to requests if it exists
api.interceptors.request.use((config) => {
  try {
    const userStr = localStorage.getItem('user')
    if (userStr) {
      const user = JSON.parse(userStr)
      if (user && user.ID) {  // Changed from id to ID to match Go struct
        config.headers.Authorization = `Bearer ${user.ID}`
      }
    }
  } catch (error) {
    console.error('Error setting auth header:', error)
  }
  return config
})

// Add response interceptor for error handling
api.interceptors.response.use(
    (response) => {
      // Ensure the response data is an object
      if (response.data && typeof response.data === 'object') {
        return response
      }
      throw new Error('Неверный формат ответа от сервера')
    },
    (error) => {
      if (error.response) {
        // Server responded with error status
        const message = error.response.data?.error || 'Ошибка сервера'
        throw new Error(message)
      } else if (error.request) {
        // Request made but no response
        throw new Error('Нет ответа от сервера. Проверьте подключение.')
      } else {
        // Request setup error
        throw new Error('Ошибка при выполнении запроса')
      }
    }
)

// Auth endpoints
export const auth = {
  register: (data: RegisterRequest): Promise<{ data: RegisterResponse }> =>
      api.post('/api/v1/register', data),

  login: (data: LoginRequest): Promise<{ data: LoginResponse }> =>
      api.post('/api/v1/login', data),
}

// User validation endpoints
export const userValidation = {
  getValidationTickets: (params?: GetValidationTicketsRequest): Promise<{ data: GetValidationTicketsResponse }> =>
      api.get('/api/v1/users/validations', { params }),

  getValidationTicketById: (id: string): Promise<{ data: GetValidationTicketByIdResponse }> =>
      api.get(`/api/v1/users/validation/${id}`),

  updateValidationStatus: (
      id: string,
      data: UpdateValidationStatusByTicketIdRequest
  ): Promise<{ data: UpdateValidationStatusByTicketIdResponse }> =>
      api.put(`/api/v1/users/validation/${id}`, data),
}

// Company validation endpoints
export const companyValidation = {
  getValidationTickets: (): Promise<{ data: CompanyValidationTicket[] }> =>
      api.get('/api/v1/companies/validations'),

  getValidationTicketById: (id: string): Promise<{ data: CompanyValidationTicket }> =>
      api.get(`/api/v1/companies/validation/${id}`),

  updateValidationStatus: (
      id: string,
      data: UpdateValidationStatusByTicketIdRequest
  ): Promise<{ data: UpdateValidationStatusByTicketIdResponse }> =>
      api.put(`/api/v1/companies/validation/${id}`, data),
}

// Dashboard endpoints
export const dashboard = {
  getDashboardData: (): Promise<{ data: DashboardData }> =>
      api.get('/api/v1/dashboard'),
}