import React, { useState, useEffect } from 'react'
import { Filter, Search, ChevronDown, ChevronUp, Check, X, ExternalLink, FileText, Download, CreditCard } from 'lucide-react'
import { userValidation } from '../api'
import { Ticket, GetValidationTicketsRequest, UpdateValidationStatusByTicketIdRequest } from '../types/api'
import toast from 'react-hot-toast'

const TicketBalances: React.FC = () => {
  const [filterOpen, setFilterOpen] = useState(false)
  const [sortColumn, setSortColumn] = useState('date')
  const [sortDirection, setSortDirection] = useState('desc')
  const [selectedStatus, setSelectedStatus] = useState<string[]>([])
  const [ticketList, setTicketList] = useState<Ticket[]>([])
  const [isLoading, setIsLoading] = useState(false)
  const [activeTicket, setActiveTicket] = useState<string | null>(null)
  const [ticketDetails, setTicketDetails] = useState<Ticket | null>(null)
  const [comment, setComment] = useState('')

  useEffect(() => {
    fetchTickets()
  }, [])

  useEffect(() => {
    if (activeTicket) {
      fetchTicketDetails(activeTicket)
    }
  }, [activeTicket])

  const fetchTickets = async () => {
    setIsLoading(true)
    try {
      const response = await userValidation.getValidationTickets()
      setTicketList(response.data.tickets)
    } catch (error) {
      console.error('Error fetching tickets:', error)
      toast.error('Ошибка при загрузке тикетов')
    } finally {
      setIsLoading(false)
    }
  }

  const fetchTicketDetails = async (id: string) => {
    try {
      const response = await userValidation.getValidationTicketById(id)
      setTicketDetails(response.data.ticket)
    } catch (error) {
      console.error('Error fetching ticket details:', error)
      toast.error('Ошибка при загрузке деталей тикета')
    }
  }

  const handleStatusUpdate = async (id: string, newStatus: string) => {
    if (!ticketDetails) return

    const updateData: UpdateValidationStatusByTicketIdRequest = {
      old_status: ticketDetails.status,
      new_status: newStatus,
      corrections: comment || undefined
    }

    try {
      await userValidation.updateValidationStatus(id, updateData)
      toast.success(`Статус успешно обновлен: ${newStatus === 'approved' ? 'Одобрен' : 'Отклонен'}`)
      fetchTickets()
      setActiveTicket(null)
      setComment('')
    } catch (error) {
      console.error('Error updating status:', error)
      toast.error('Ошибка при обновлении статуса')
    }
  }

  const handleSort = (column: string) => {
    if (sortColumn === column) {
      setSortDirection(sortDirection === 'asc' ? 'desc' : 'asc')
    } else {
      setSortColumn(column)
      setSortDirection('asc')
    }
  }

  const toggleStatus = (status: string) => {
    if (selectedStatus.includes(status)) {
      setSelectedStatus(selectedStatus.filter(s => s !== status))
    } else {
      setSelectedStatus([...selectedStatus, status])
    }
  }

  const filteredTickets = ticketList.filter(ticket => {
    if (selectedStatus.length === 0) return true
    return selectedStatus.includes(ticket.status)
  })

  const sortedTickets = [...filteredTickets].sort((a, b) => {
    if (sortColumn === 'last_update') {
      return sortDirection === 'asc' 
        ? new Date(a.last_update).getTime() - new Date(b.last_update).getTime()
        : new Date(b.last_update).getTime() - new Date(a.last_update).getTime()
    } else {
      const valueA = a[sortColumn as keyof typeof a]?.toString().toLowerCase() ?? ''
      const valueB = b[sortColumn as keyof typeof b]?.toString().toLowerCase() ?? ''
      return sortDirection === 'asc'
        ? valueA.localeCompare(valueB)
        : valueB.localeCompare(valueA)
    }
  })

  const getStatusBadge = (status: string) => {
    switch (status) {
      case 'approved':
        return <span className="badge badge-success">Одобрен</span>
      case 'rejected':
        return <span className="badge badge-danger">Отклонен</span>
      case 'pending':
        return <span className="badge badge-warning">На рассмотрении</span>
      default:
        return <span className="badge badge-info">В обработке</span>
    }
  }

  const getSortIcon = (column: string) => {
    if (sortColumn !== column) return null
    return sortDirection === 'asc' ? <ChevronUp className="w-4 h-4" /> : <ChevronDown className="w-4 h-4" />
  }

  if (isLoading) {
    return (
      <div className="flex items-center justify-center min-h-screen">
        <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-primary"></div>
      </div>
    )
  }

  return (
    <div>
      <div className="mb-6">
        <h1 className="text-2xl font-bold text-gray-900">Тикеты на балансы</h1>
        <p className="mt-1 text-sm text-gray-500">
          Управление запросами на пополнение и вывод средств
        </p>
      </div>

      <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
        <div className="lg:col-span-2">
          <div className="card">
            <div className="p-6 border-b border-gray-200">
              <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
                <div className="relative w-full md:w-64">
                  <div className="absolute inset-y-0 left-0 flex items-center pl-3 pointer-events-none">
                    <Search className="w-5 h-5 text-gray-400" />
                  </div>
                  <input
                    type="text"
                    className="input pl-10"
                    placeholder="Поиск по ID, имени..."
                  />
                </div>
                <div className="flex items-center gap-2">
                  <button
                    className="btn btn-outline flex items-center gap-2"
                    onClick={() => setFilterOpen(!filterOpen)}
                  >
                    <Filter className="w-4 h-4" />
                    Фильтры
                    {selectedStatus.length > 0 && (
                      <span className="bg-primary text-white text-xs rounded-full w-5 h-5 flex items-center justify-center">
                        {selectedStatus.length}
                      </span>
                    )}
                  </button>
                  <button className="btn btn-primary">
                    Экспорт
                  </button>
                </div>
              </div>

              {filterOpen && (
                <div className="mt-4 p-4 border border-gray-200 rounded-md bg-gray-50">
                  <h4 className="font-medium text-gray-700 mb-2">Статус</h4>
                  <div className="flex flex-wrap gap-2">
                    <button
                      className={`btn ${selectedStatus.includes('pending') ? 'bg-yellow-100 text-yellow-800 border-yellow-300' : 'btn-outline'}`}
                      onClick={() => toggleStatus('pending')}
                    >
                      На рассмотрении
                    </button>
                    <button
                      className={`btn ${selectedStatus.includes('approved') ? 'bg-green-100 text-green-800 border-green-300' : 'btn-outline'}`}
                      onClick={() => toggleStatus('approved')}
                    >
                      Одобрен
                    </button>
                    <button
                      className={`btn ${selectedStatus.includes('rejected') ? 'bg-red-100 text-red-800 border-red-300' : 'btn-outline'}`}
                      onClick={() => toggleStatus('rejected')}
                    >
                      Отклонен
                    </button>
                  </div>
                </div>
              )}
            </div>

            <div className="overflow-x-auto">
              <table className="min-w-full divide-y divide-gray-200">
                <thead className="bg-gray-50">
                  <tr>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('ticket_id')}
                    >
                      <div className="flex items-center gap-1">
                        ID {getSortIcon('ticket_id')}
                      </div>
                    </th>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('name')}
                    >
                      <div className="flex items-center gap-1">
                        Пользователь {getSortIcon('name')}
                      </div>
                    </th>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('description')}
                    >
                      <div className="flex items-center gap-1">
                        Описание {getSortIcon('description')}
                      </div>
                    </th>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('status')}
                    >
                      <div className="flex items-center gap-1">
                        Статус {getSortIcon('status')}
                      </div>
                    </th>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('last_update')}
                    >
                      <div className="flex items-center gap-1">
                        Дата {getSortIcon('last_update')}
                      </div>
                    </th>
                    <th scope="col" className="px-6 py-3 text-right text-xs font-medium text-gray-500 uppercase tracking-wider">
                      Действия
                    </th>
                  </tr>
                </thead>
                <tbody className="bg-white divide-y divide-gray-200">
                  {sortedTickets.map((ticket) => (
                    <tr 
                      key={ticket.ticket_id} 
                      className={`hover:bg-gray-50 cursor-pointer ${activeTicket === ticket.ticket_id ? 'bg-primary-50' : ''}`}
                      onClick={() => setActiveTicket(ticket.ticket_id)}
                    >
                      <td className="px-6 py-4 whitespace-nowrap text-sm font-medium text-primary">
                        {ticket.ticket_id}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-900">
                        <div>{ticket.name}</div>
                        <div className="text-gray-500 text-xs">{ticket.email}</div>
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-900">
                        {ticket.description || '-'}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm">
                        {getStatusBadge(ticket.status)}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-500">
                        {new Date(ticket.last_update).toLocaleDateString()}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-right text-sm font-medium">
                        <div className="flex justify-end gap-2">
                          {ticket.status === 'pending' && (
                            <>
                              <button 
                                className="p-1 text-green-600 hover:text-green-900" 
                                title="Одобрить"
                                onClick={(e) => {
                                  e.stopPropagation()
                                  handleStatusUpdate(ticket.ticket_id, 'approved')
                                }}
                              >
                                <Check className="w-5 h-5" />
                              </button>
                              <button 
                                className="p-1 text-red-600 hover:text-red-900" 
                                title="Отклонить"
                                onClick={(e) => {
                                  e.stopPropagation()
                                  handleStatusUpdate(ticket.ticket_id, 'rejected')
                                }}
                              >
                                <X className="w-5 h-5" />
                              </button>
                            </>
                          )}
                          <button 
                            className="p-1 text-primary hover:text-primary-700" 
                            title="Подробнее"
                            onClick={(e) => {
                              e.stopPropagation()
                              setActiveTicket(ticket.ticket_id)
                            }}
                          >
                            <ExternalLink className="w-5 h-5" />
                          </button>
                        </div>
                      </td>
                    </tr>
                  ))}
                </tbody>
              </table>
            </div>

            <div className="px-6 py-4 border-t border-gray-200 flex items-center justify-between">
              <div className="text-sm text-gray-700">
                Показано <span className="font-medium">{sortedTickets.length}</span> из <span className="font-medium">{ticketList.length}</span> тикетов
              </div>
            </div>
          </div>
        </div>

        <div className="lg:col-span-1">
          {ticketDetails ? (
            <div className="card">
              <div className="p-6 border-b border-gray-200">
                <div className="flex items-center">
                  <div className="h-12 w-12 rounded-full bg-primary-100 flex items-center justify-center text-primary-600 font-medium text-lg">
                    {ticketDetails.name.split(' ').map(n => n[0]).join('')}
                  </div>
                  <div className="ml-4">
                    <h3 className="text-lg font-medium text-gray-900">{ticketDetails.name}</h3>
                    <p className="text-sm text-gray-500">{ticketDetails.ticket_id}</p>
                  </div>
                </div>
              </div>
              <div className="p-6">
                <div className="space-y-4">
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Email</h4>
                    <p className="mt-1 text-sm text-gray-900">{ticketDetails.email}</p>
                  </div>
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Телефон</h4>
                    <p className="mt-1 text-sm text-gray-900">{ticketDetails.phone}</p>
                  </div>
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Статус</h4>
                    <div className="mt-1">{getStatusBadge(ticketDetails.status)}</div>
                  </div>
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Дата обновления</h4>
                    <p className="mt-1 text-sm text-gray-900">
                      {new Date(ticketDetails.last_update).toLocaleString()}
                    </p>
                  </div>
                  {ticketDetails.description && (
                    <div>
                      <h4 className="text-sm font-medium text-gray-500">Описание</h4>
                      <p className="mt-1 text-sm text-gray-900">{ticketDetails.description}</p>
                    </div>
                  )}
                </div>
              </div>
              {ticketDetails.status === 'pending' && (
                <div className="p-6 border-t border-gray-200">
                  <div className="flex gap-2">
                    <button 
                      className="btn btn-primary flex-1"
                      onClick={() => handleStatusUpdate(ticketDetails.ticket_id, 'approved')}
                    >
                      Одобрить
                    </button>
                    <button 
                      className="btn btn-outline text-red-600 border-red-300 hover:bg-red-50 flex-1"
                      onClick={() => handleStatusUpdate(ticketDetails.ticket_id, 'rejected')}
                    >
                      Отклонить
                    </button>
                  </div>
                  <div className="mt-4">
                    <label htmlFor="comment" className="label">Комментарий</label>
                    <textarea
                      id="comment"
                      rows={3}
                      className="input"
                      placeholder="Добавьте комментарий к решению..."
                      value={comment}
                      onChange={(e) => setComment(e.target.value)}
                    ></textarea>
                  </div>
                </div>
              )}
            </div>
          ) : (
            <div className="card p-6 text-center">
              <div className="text-gray-500">
                <CreditCard className="w-12 h-12 mx-auto text-gray-400" />
                <h3 className="mt-2 text-sm font-medium text-gray-900">Выберите тикет</h3>
                <p className="mt-1 text-sm text-gray-500">Выберите тикет из списка для просмотра подробной информации</p>
              </div>
            </div>
          )}
        </div>
      </div>
    </div>
  )
}

export default TicketBalances