import React, { useState, useEffect } from 'react'
import { Filter, Search, ChevronDown, ChevronUp, Check, X, ExternalLink, User, Download, FileText } from 'lucide-react'
import { userValidation } from '../api'
import { ValidationTicket } from '../types/api'
import toast from 'react-hot-toast'

const UserValidation: React.FC = () => {
  const [filterOpen, setFilterOpen] = useState(false)
  const [sortColumn, setSortColumn] = useState('date')
  const [sortDirection, setSortDirection] = useState('desc')
  const [selectedStatus, setSelectedStatus] = useState<string[]>([])
  const [activeUser, setActiveUser] = useState<string | null>(null)
  const [tickets, setTickets] = useState<ValidationTicket[]>([])
  const [isLoading, setIsLoading] = useState(false)
  const [activeTicket, setActiveTicket] = useState<ValidationTicket | null>(null)
  const [comment, setComment] = useState('')

  useEffect(() => {
    fetchTickets()
  }, [])

  useEffect(() => {
    if (activeUser) {
      fetchTicketDetails(activeUser)
    }
  }, [activeUser])

  const fetchTickets = async () => {
    setIsLoading(true)
    try {
      const response = await userValidation.getValidationTickets()
      setTickets(response.data)
    } catch (error) {
      console.error('Error fetching tickets:', error)
      toast.error('Ошибка при загрузке тикетов')
    } finally {
      setIsLoading(false)
    }
  }

  const fetchTicketDetails = async (id: string) => {
    try {
      const response = await userValidation.getValidationTicketById(id)
      setActiveTicket(response.data)
    } catch (error) {
      console.error('Error fetching ticket details:', error)
      toast.error('Ошибка при загрузке деталей тикета')
    }
  }

  const handleStatusUpdate = async (id: string, status: 'approved' | 'rejected') => {
    try {
      await userValidation.updateValidationStatus(id, { status, comment })
      toast.success(`Статус успешно обновлен: ${status === 'approved' ? 'Одобрен' : 'Отклонен'}`)
      fetchTickets() // Refresh the list
      setActiveUser(null) // Reset active user
      setComment('') // Reset comment
    } catch (error) {
      console.error('Error updating status:', error)
      toast.error('Ошибка при обновлении статуса')
    }
  }

  const handleSort = (column: string) => {
    if (sortColumn === column) {
      setSortDirection(sortDirection === 'asc' ? 'desc' : 'asc')
    } else {
      setSortColumn(column)
      setSortDirection('asc')
    }
  }

  const toggleStatus = (status: string) => {
    if (selectedStatus.includes(status)) {
      setSelectedStatus(selectedStatus.filter(s => s !== status))
    } else {
      setSelectedStatus([...selectedStatus, status])
    }
  }

  const filteredUsers = tickets.filter(user => {
    if (selectedStatus.length === 0) return true
    return selectedStatus.includes(user.status)
  })

  const sortedUsers = [...filteredUsers].sort((a, b) => {
    if (sortColumn === 'date') {
      return sortDirection === 'asc' 
        ? new Date(a.date).getTime() - new Date(b.date).getTime()
        : new Date(b.date).getTime() - new Date(a.date).getTime()
    } else {
      const valueA = a[sortColumn as keyof typeof a].toString().toLowerCase()
      const valueB = b[sortColumn as keyof typeof b].toString().toLowerCase()
      return sortDirection === 'asc'
        ? valueA.localeCompare(valueB)
        : valueB.localeCompare(valueA)
    }
  })

  const getStatusBadge = (status: string) => {
    switch (status) {
      case 'approved':
        return <span className="badge badge-success">Подтвержден</span>
      case 'rejected':
        return <span className="badge badge-danger">Отклонен</span>
      case 'pending':
        return <span className="badge badge-warning">На проверке</span>
      default:
        return <span className="badge badge-info">В обработке</span>
    }
  }

  const getSortIcon = (column: string) => {
    if (sortColumn !== column) return null
    return sortDirection === 'asc' ? <ChevronUp className="w-4 h-4" /> : <ChevronDown className="w-4 h-4" />
  }

  if (isLoading) {
    return (
      <div className="flex items-center justify-center min-h-screen">
        <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-primary"></div>
      </div>
    )
  }

  return (
    <div>
      <div className="mb-6">
        <h1 className="text-2xl font-bold text-gray-900">Валидация пользователей</h1>
        <p className="mt-1 text-sm text-gray-500">
          Проверка и подтверждение личности пользователей
        </p>
      </div>

      <div className="grid grid-cols-1 lg:grid-cols-3 gap-6">
        <div className="lg:col-span-2">
          <div className="card">
            <div className="p-6 border-b border-gray-200">
              <div className="flex flex-col md:flex-row md:items-center md:justify-between gap-4">
                <div className="relative w-full md:w-64">
                  <div className="absolute inset-y-0 left-0 flex items-center pl-3 pointer-events-none">
                    <Search className="w-5 h-5 text-gray-400" />
                  </div>
                  <input
                    type="text"
                    className="input pl-10"
                    placeholder="Поиск по имени, email..."
                  />
                </div>
                <div className="flex items-center gap-2">
                  <button
                    className="btn btn-outline flex items-center gap-2"
                    onClick={() => setFilterOpen(!filterOpen)}
                  >
                    <Filter className="w-4 h-4" />
                    Фильтры
                    {selectedStatus.length > 0 && (
                      <span className="bg-primary text-white text-xs rounded-full w-5 h-5 flex items-center justify-center">
                        {selectedStatus.length}
                      </span>
                    )}
                  </button>
                </div>
              </div>

              {filterOpen && (
                <div className="mt-4 p-4 border border-gray-200 rounded-md bg-gray-50">
                  <h4 className="font-medium text-gray-700 mb-2">Статус</h4>
                  <div className="flex flex-wrap gap-2">
                    <button
                      className={`btn ${selectedStatus.includes('pending') ? 'bg-yellow-100 text-yellow-800 border-yellow-300' : 'btn-outline'}`}
                      onClick={() => toggleStatus('pending')}
                    >
                      На проверке
                    </button>
                    <button
                      className={`btn ${selectedStatus.includes('approved') ? 'bg-green-100 text-green-800 border-green-300' : 'btn-outline'}`}
                      onClick={() => toggleStatus('approved')}
                    >
                      Подтвержден
                    </button>
                    <button
                      className={`btn ${selectedStatus.includes('rejected') ? 'bg-red-100 text-red-800 border-red-300' : 'btn-outline'}`}
                      onClick={() => toggleStatus('rejected')}
                    >
                      Отклонен
                    </button>
                  </div>
                </div>
              )}
            </div>

            <div className="overflow-x-auto">
              <table className="min-w-full divide-y divide-gray-200">
                <thead className="bg-gray-50">
                  <tr>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('id')}
                    >
                      <div className="flex items-center gap-1">
                        ID {getSortIcon('id')}
                      </div>
                    </th>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('name')}
                    >
                      <div className="flex items-center gap-1">
                        Имя {getSortIcon('name')}
                      </div>
                    </th>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('email')}
                    >
                      <div className="flex items-center gap-1">
                        Email {getSortIcon('email')}
                      </div>
                    </th>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('status')}
                    >
                      <div className="flex items-center gap-1">
                        Статус {getSortIcon('status')}
                      </div>
                    </th>
                    <th 
                      scope="col" 
                      className="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider cursor-pointer"
                      onClick={() => handleSort('date')}
                    >
                      <div className="flex items-center gap-1">
                        Дата {getSortIcon('date')}
                      </div>
                    </th>
                    <th scope="col" className="px-6 py-3 text-right text-xs font-medium text-gray-500 uppercase tracking-wider">
                      Действия
                    </th>
                  </tr>
                </thead>
                <tbody className="bg-white divide-y divide-gray-200">
                  {sortedUsers.map((user) => (
                    <tr 
                      key={user.id} 
                      className={`hover:bg-gray-50 cursor-pointer ${activeUser === user.id ? 'bg-primary-50' : ''}`}
                      onClick={() => setActiveUser(user.id)}
                    >
                      <td className="px-6 py-4 whitespace-nowrap text-sm font-medium text-primary">
                        {user.id}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-900">
                        {user.name}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-900">
                        {user.email}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm">
                        {getStatusBadge(user.status)}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-sm text-gray-500">
                        {user.date}
                      </td>
                      <td className="px-6 py-4 whitespace-nowrap text-right text-sm font-medium">
                        <div className="flex justify-end gap-2">
                          {user.status === 'pending' && (
                            <>
                              <button 
                                className="p-1 text-green-600 hover:text-green-900" 
                                title="Подтвердить"
                                onClick={(e) => {
                                  e.stopPropagation();
                                  handleStatusUpdate(user.id, 'approved');
                                }}
                              >
                                <Check className="w-5 h-5" />
                              </button>
                              <button 
                                className="p-1 text-red-600 hover:text-red-900" 
                                title="Отклонить"
                                onClick={(e) => {
                                  e.stopPropagation();
                                  handleStatusUpdate(user.id, 'rejected');
                                }}
                              >
                                <X className="w-5 h-5" />
                              </button>
                            </>
                          )}
                          <button 
                            className="p-1 text-primary hover:text-primary-700" 
                            title="Подробнее"
                            onClick={(e) => {
                              e.stopPropagation();
                              setActiveUser(user.id);
                            }}
                          >
                            <ExternalLink className="w-5 h-5" />
                          </button>
                        </div>
                      </td>
                    </tr>
                  ))}
                </tbody>
              </table>
            </div>

            <div className="px-6 py-4 border-t border-gray-200 flex items-center justify-between">
              <div className="text-sm text-gray-700">
                Показано <span className="font-medium">{sortedUsers.length}</span> из <span className="font-medium">{tickets.length}</span> пользователей
              </div>
            </div>
          </div>
        </div>

        <div className="lg:col-span-1">
          {activeTicket ? (
            <div className="card">
              <div className="p-6 border-b border-gray-200">
                <div className="flex items-center">
                  <div className="h-12 w-12 rounded-full bg-primary-100 flex items-center justify-center text-primary-600 font-medium text-lg">
                    {activeTicket.name.split(' ').map(n => n[0]).join('')}
                  </div>
                  <div className="ml-4">
                    <h3 className="text-lg font-medium text-gray-900">{activeTicket.name}</h3>
                    <p className="text-sm text-gray-500">{activeTicket.id}</p>
                  </div>
                </div>
              </div>
              <div className="p-6">
                <div className="space-y-4">
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Email</h4>
                    <p className="mt-1 text-sm text-gray-900">{activeTicket.email}</p>
                  </div>
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Телефон</h4>
                    <p className="mt-1 text-sm text-gray-900">{activeTicket.phone}</p>
                  </div>
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Статус</h4>
                    <div className="mt-1">{getStatusBadge(activeTicket.status)}</div>
                  </div>
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Дата регистрации</h4>
                    <p className="mt-1 text-sm text-gray-900">{activeTicket.date}</p>
                  </div>
                  <div>
                    <h4 className="text-sm font-medium text-gray-500">Документы</h4>
                    <div className="mt-2 space-y-2">
                      {activeTicket.documents.map((doc, index) => (
                        <div key={index} className="flex items-center justify-between p-2 bg-gray-50 rounded-md">
                          <div className="flex items-center">
                            <FileText className="w-5 h-5 text-gray-500 mr-2" />
                            <span className="text-sm text-gray-900">{doc}</span>
                          </div>
                          <button className="text-primary hover:text-primary-700">
                            <Download className="w-5 h-5" />
                          </button>
                        </div>
                      ))}
                    </div>
                  </div>
                </div>
              </div>
              {activeTicket.status === 'pending' && (
                <div className="p-6 border-t border-gray-200">
                  <div className="flex gap-2">
                    <button 
                      className="btn btn-primary flex-1"
                      onClick={() => handleStatusUpdate(activeTicket.id, 'approved')}
                    >
                      Подтвердить
                    </button>
                    <button 
                      className="btn btn-outline text-red-600 border-red-300 hover:bg-red-50 flex-1"
                      onClick={() => handleStatusUpdate(activeTicket.id, 'rejected')}
                    >
                      Отклонить
                    </button>
                  </div>
                  <div className="mt-4">
                    <label htmlFor="comment" className="label">Комментарий</label>
                    <textarea
                      id="comment"
                      rows={3}
                      className="input"
                      placeholder="Добавьте комментарий к решению..."
                      value={comment}
                      onChange={(e) => setComment(e.target.value)}
                    ></textarea>
                  </div>
                </div>
              )}
            </div>
          ) : (
            <div className="card p-6 text-center">
              <div className="text-gray-500">
                <User className="w-12 h-12 mx-auto text-gray-400" />
                <h3 className="mt-2 text-sm font-medium text-gray-900">Выберите пользователя</h3>
                <p className="mt-1 text-sm text-gray-500">Выберите пользователя из списка для просмотра подробной информации</p>
              </div>
            </div>
          )}
        </div>
      </div>
    </div>
  )
}

export default UserValidation